@@ -79,7 +79,7 @@ class Mock(object):
             # we throw away the first argument, if it's either self or cls
             if (inspect.ismethod(new_mocked_method) or
                     inspect.isclass(self.mocked_obj) and
-                    not isinstance(original_method, staticmethod)):
+                    not isinstance(new_mocked_method, staticmethod)):
                 args = args[1:]
 
             return remembered_invocation_builder(
@@ -89,6 +89,10 @@ class Mock(object):
         if original_method:
             new_mocked_method.__doc__ = original_method.__doc__
             new_mocked_method.__wrapped__ = original_method
+            try:
+                new_mocked_method.__module__ = original_method.__module__
+            except AttributeError:
+                pass
 
         if (inspect.ismethod(original_method)):
             new_mocked_method = utils.newmethod(
@@ -97,6 +101,8 @@ class Mock(object):
             new_mocked_method = staticmethod(new_mocked_method)
         elif isinstance(original_method, classmethod):
             new_mocked_method = classmethod(new_mocked_method)
+        elif inspect.isclass(original_method):
+            new_mocked_method = staticmethod(new_mocked_method)
 
         self.set_method(method_name, new_mocked_method)
 
